# UTKPAD: Replay Attack Database for Face Age Verification

## Introduction

UTKPAD is a replay attack database prepared for face age verification as part of the paper 
"Vulnerability of Face Age Verification to Replay Attacks" published in ICASSP 2024 confernece. 
This database is originated from the well-known large dataset, UTKFace [1] of face images with age labels 
ranging from 1 to 100 plus years old. With UTKPAD database, we also provide file lists that can be used 
for training and testing of replay attacks detection and for vulnerability assessment of age verification systems.

## Dataset

The face images in the UTKFace are first enhanced with a face restoration CodeFormer [3] method. 
Each enhanced image is converted into a video clip with a subsequent concatenation process to have one video clip 
including all image-to-video converted files. The final video clip is then replayed on Apple iPad Pro in order 
to record it with three different mobiles phones: Apple iPhone 12, Samsung Galaxy S9 and Huawei Mate 30.
And, finally, the recordings are de-concatenated/segmented into sub video clips and each video clip is sampled by taking 
the middle frame to construct the database of replay attack images.

### The release specifics and how to obtain the actual images

Due to unclear copyright of the original images in UTKFace dataset, we could not re-distribute the 
images (even if they are modified in form of replay attacks) as is. Therefore, we actually do not
provide images of the relay attacks directly but in the form of pixle-wise deltas (`delta=attack_image-bonafide_image`), 
which would require the original UTKFace images to restore the corresponding attacks recorded by us. 

Hence, we emplore the potential users of our dataset to download the original UTKFace separately and place it in its 
entirety inside a 'bonafide' folder (the folder should have structrue `bonafide/part1`, `bonafide/part2`, and 
`bonafide/part3` of the original). Using this bonafide data and the deltas that we provide for each replay attack, you then 
can run the provided script `recover-utkpad-from-deltas.py` to restore all the attack images (`attack_image=delta+bonafide_image`).
The script `recover-utkpad-from-deltas.py` need to be run with the root folder path as the input, 
e.g., `recover-utkpad-from-deltas.py ./`. 
As the dependencies, the script requires only `docopt`, `numpy`, and `opencv` to be installed in the python environment. 

### The details of the dataset

All image names in UTKPAD are the same as in the original UTKFace, the only difference is the folder 
where they are stored. We assume that the user downloads the original UTKFace into `bonafide` folder, 
which would then contain the original un-processed/un-enhanced images of UTKFace.
We provide the other three folders that contain the deltas between original images and the replay attacks 
recorded by the corresponding smartphones. 

We also provide file lists for training and testing, which contain relative paths to the images
and the path to an actual (bonafide or attack) image can be constructed by appending the 
folder name (bonafide or the one of the specific attack) at the start of the relative path. 
So, using these file lists, it is easy to create either evaluation protocols 
for replay attack detection methods or for vulnerability assessment of age verification systems. 
File list for training contains 20601 images and for testing 3504 images. Hence, by appending the folder name 
(bonafide or one of the specific attacks), one can create 4 training and 4 test lists. We also provide 
two types of lists, one with the relative path to the images and exact age label as per the info from UTKFace 
and another with categorical age label. The range of exact age distribution is between 1 and 116 and the categorical age label 
is one of the 7 categories: 'childhood' (below 8 years old), 'puberty' (between 8 and 13), 'adolescence' (between 13 and 18), 
'early adulthood' (between 18 and 25), 'adulthood' (between 25 and 35), 'middle age' (between 35 and 50), and 'seniority' (above 50). 

### File Structure

The file structure is listed as below:

	* bonafide: an empty folder where `part1`, `part2`, and `part3` subfolders with the original images from UTKFace dataset need to be placed.
	* play-ipadpro-record-iphone12-deltas: folder with deltas of images replayed with iPad Pro and recorded with iPhone 12.
	* play-ipadpro-record-galaxys9-deltas: folder with deltas of images replayed with iPad Pro and recorded with Galaxy S9.
	* play-ipadpro-record-huaweimate30-deltas: folder with deltas of images replayed with iPad Pro and recorded with Huawei Mate 30.
	* train-set-age-label.csv: relative paths to images in the training set with exact age labels.
	* train-set-7category-label.csv: relative paths to images in the training set with categorical age labels.
	* test-set-age-label.csv: relative paths to images in the test set with exact age labels.
	* test-set-7category-label.csv: relative paths to images in the test set with categorical age labels.
    * recover-utkpad-from-deltas.py: the script that should be run inside this folder to restore the attack images using `bonafide` and all `*-deltas` subfolders.

## Evaluation

An example of how the database is used to assess vulnerability of face age verification systems 
can be found as a Jupyter notebook file (`evaluate-age-verification.ipynb`) in the source package [4]. 
All evaluation scores, which were reported in the paper, can also be found in the source package [4].

## Contact and Citation

For any kind of queries regarding to the database, please contact Pavel Korshunov <pavel.korshunov@idiap.ch>

And, if you use the database, please cite the following paper:

```
    @INPROCEEDINGS{Korshunov_ICASSP_2024,
            author = {Korshunov, Pavel and George, Anjith and {\"O}zbulak, G{\"o}khan and Marcel, S{\'{e}}bastien},
        projects = {Idiap, Biometrics Center},
            title = {Vulnerablity of Face Age Verification to Replay Attacks},
        booktitle = {ICASSP 2024 - 2024 IEEE International Conference on Acoustics, Speech and Signal Processing (ICASSP)},
            year = {2024},
    }
```

## References

- [1] Z. Zhang, Y. Song, and H. Qi, “Age progression/regression by conditional adversarial autoencoder,” 
in IEEE Conference on Computer Vision and Pattern Recognition (CVPR), 2017, pp. 4352–4360.
- [2] https://www.privately.eu
- [3] S. Zhou, K. C. Chan, C. Li, and C. C. Loy, “Towards robust blind face restoration with codebook lookup transformer,” 
in Advances in Neural Information Processing System (NeurIPS), 2022.
- [4] https://gitlab.idiap.ch/biometric/icassp2024.agepad
